==> phpgroupware-jp-0.9.16.003-pre1.tar.bz2: phpgroupware/phpsysinfo/includes/lang/br.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: br.php,v 1.1.1.2 2004/04/06 23:17:13 kazuyan Exp $
// Translated by lvaro Reguly - alvaro at reguly dot net

$text['title']          = 'Informaes do Sistema';

$text['vitals']         = 'Sistema';
$text['hostname']       = 'Nome Cannico';
$text['ip']             = 'Nmeros IP';
$text['kversion']       = 'Verso do Kernel';
$text['uptime']         = 'Uptime';
$text['users']          = 'Usurios Conectados';
$text['loadavg']        = 'Carga do Sistema';

$text['hardware']       = 'Informaes do Hardware';
$text['numcpu']         = 'Processadores';
$text['cpumodel']       = 'Modelo';
$text['mhz']            = 'MHz';
$text['cache']          = 'Tamanho Cache';
$text['bogomips']       = 'Bogomips';
$text['pci']            = 'Dispositivos PCI';
$text['ide']            = 'Dispositivos IDE';
$text['scsi']           = 'Dispositivos SCSI';

$text['netusage']       = 'Utilizao da Rede';
$text['device']         = 'Dispositivo';
$text['received']       = 'Recebidos';
$text['sent']           = 'Enviados';
$text['errors']         = 'Erros/Drop';

$text['memusage']       = 'Utilizao da Memria';
$text['phymem']         = 'Memria Fsica';
$text['swap']           = 'Swap';

$text['fs']             = 'Sistemas de Arquivo Montados';
$text['mount']          = 'Mount';
$text['partition']      = 'Partio';

$text['percent']        = 'Porcentual da Capacidade';
$text['type']           = 'Tipo';
$text['free']           = 'Livres';
$text['used']           = 'Utilizados';
$text['size']           = 'Tamanho';
$text['totals']         = 'Totais';

$text['kb']             = 'KB';
$text['mb']             = 'MB';
$text['gb']             = 'GB';

$text['none']           = 'nenhum';

$text['capacity']       = 'Capacidade';

$text['template']       = 'Molde';
$text['language']       = 'Lngua';
$text['submit']         = 'Enviar';
$text['created']        = 'Criado por';

$text['days']           = 'dias';
$text['hours']          = 'horas';
$text['minutes']        = 'minutos';
?>

==> phpgroupware-jp-0.9.16.012-pre1.tar.bz2: phpgroupware/phpsysinfo/includes/lang/br.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: br.php,v 1.1.1.3 2007/09/13 20:19:58 kazuyan Exp $
// Translated by lvaro Reguly - alvaro at reguly dot net
//
$text['title']          = 'Informaes do Sistema';

$text['vitals']         = 'Sistema';
$text['hostname']       = 'Nome Cannico';
$text['ip']             = 'Nmeros IP';
$text['kversion']       = 'Verso do Kernel';
$text['dversion']       = 'Distro Name';
$text['uptime']         = 'Uptime';
$text['users']          = 'Usurios Conectados';
$text['loadavg']        = 'Carga do Sistema';

$text['hardware']       = 'Informaes do Hardware';
$text['numcpu']         = 'Processadores';
$text['cpumodel']       = 'Modelo';
$text['cpuspeed']       = 'CPU Speed';
$text['busspeed']       = 'BUS Speed';
$text['cache']          = 'Tamanho Cache';
$text['bogomips']       = 'Bogomips';

$text['pci']            = 'Dispositivos PCI';
$text['ide']            = 'Dispositivos IDE';
$text['scsi']           = 'Dispositivos SCSI';
$text['usb']            = 'Dispositivos USB';

$text['netusage']       = 'Utilizao da Rede';
$text['device']         = 'Dispositivo';
$text['received']       = 'Recebidos';
$text['sent']           = 'Enviados';
$text['errors']         = 'Erros/Drop';

$text['memusage']       = 'Utilizao da Memria';
$text['phymem']         = 'Memria Fsica';
$text['swap']           = 'Swap';

$text['fs']             = 'Sistemas de Arquivo Montados';
$text['mount']          = 'Mount';
$text['partition']      = 'Partio';

$text['percent']        = 'Porcentual da Capacidade';
$text['type']           = 'Tipo';
$text['free']           = 'Livres';
$text['used']           = 'Utilizados';
$text['size']           = 'Tamanho';
$text['totals']         = 'Totais';

$text['kb']             = 'KB';
$text['mb']             = 'MB';
$text['gb']             = 'GB';

$text['none']           = 'nenhum';

$text['capacity']       = 'Capacidade';

$text['template']       = 'Molde';
$text['language']       = 'Lngua';
$text['submit']         = 'Enviar';
$text['created']        = 'Criado por';
$text['locale']         = 'en_US';
$text['gen_time']       = 'on %b %d, %Y at %I:%M %p';

$text['days']           = 'dias';
$text['hours']          = 'horas';
$text['minutes']        = 'minutos';

$text['temperature']    = 'Temperature';
$text['voltage']        = 'Voltage';
$text['fans']           = 'Fans';
$text['s_value']        = 'Value';
$text['s_min']          = 'Min';
$text['s_max']          = 'Max';
$text['hysteresis']     = 'Hysteresis';
$text['s_limit']        = 'Limit';
$text['s_label']        = 'Label';
$text['degreeC']        = '&deg;C';
$text['degreeF']        = '&deg;F';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

$text['app']		= 'Kernel + applications';
$text['buffers']	= 'Buffers';
$text['cached']		= 'Cached';

$text['connections']	= 'Established Network Connections';
?>
